#  -*- coding: utf-8 -*-
# *****************************************************************************
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Module authors:
#   Markus Zolliker <markus.zolliker@psi.ch>
#
# *****************************************************************************

#import os
from servicemanager.base import ServiceManager, ServiceDown, UsageError


class FrappyManager(ServiceManager):
    group = 'frappy'
    services = ('main', 'stick', 'addons')
    USAGE = """
    Usage:

      frappy list [<instance>]
      frappy start <instance> <service> <cfgfiles>
      frappy restart <instance> [<service>] [<cfgfiles>]
      frappy stop <instance> [<service>]

      <service> is one of main, stick, addons
      <instance> is one of %s
    """

    def do_gui(self, ins='', service='main'):
        try:
            self.check_running(ins, service)
        except ServiceDown as e:
            raise UsageError('frappy %s %s is not running' % (ins, service))
            return
        except KeyError:
            if not ins:
                raise UsageError('missing instance')
            raise UsageError('unknown instance %s' % ins)

        print('starting frappy gui %s' % ins)

        import mlzlog

        from secop.gui.qt import QApplication
        from secop.gui.mainwindow import MainWindow

        mlzlog.initLogging('gui', 'info')

        app = QApplication([])
        win = MainWindow(['localhost:%d' % self.info[ins][service]])
        win.show()

        return app.exec_()
